@@ -4,8 +4,6 @@ import os
 import pathlib
 import pkgutil
 
-import dcyd.utils.constants as constants
-
 
 def args_parser():
     parser = argparse.ArgumentParser(description='Configure client to communicate with dcyd.')
@@ -26,8 +24,8 @@ def args_parser():
     parser.add_argument(
         '-o', '--output-file',
         dest='config_file',
-        default=constants.CONFIG_FILE,
-        help='output config file name (default: {})'.format(constants.CONFIG_FILE)
+        default='dcyd.json',
+        help='output config file name (default: dcyd.json)'
     )
 
     return parser
